﻿// --------------------------------------------------------------------------------------
//
// ABSdemo                                                        Ulrich Müller  24.05.09
//                                                                Aspire  C# 2008 Express
// Funktionsmodell für eine ABS-Bremse
//        Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using FishFace40;

namespace ABSdemo {
  public partial class ABSmain : Form {
    Out mKompressor     = Out.M1;
    Out mBremsscheibe   = Out.M2;
    Out oMinderdruck    = Out.O5;
    Out oBremszylinder  = Out.O6;
    Out mLichtschranke  = Out.M4;
    Inp iMinderdruck    = Inp.I6;
    Inp iLichtschranke  = Inp.I7;
    Inp iBremsTaster    = Inp.I8;

    FishFace ft = new FishFace();
    Thread Drehen;
    Thread Druck;
    private void Action() {
      Drehen = new Thread(new ThreadStart(DrehenRun));
      Druck = new Thread(new ThreadStart(DruckRun));
      Drehen.IsBackground = true;
      Druck.IsBackground = true;
      Druck.Start();
      Drehen.Start();
      ft.SetMotor(mKompressor, Dir.On);
      ft.SetMotor(mBremsscheibe, Dir.On);
      ft.SetMotor(mLichtschranke, Dir.On);
      ft.Pause(1234);
      do {
        ft.WaitForInput(iBremsTaster);
        ft.SetLamp(oBremszylinder, Dir.On);
        ft.WaitForInput(iBremsTaster, false);
        ft.SetLamp(oBremszylinder, Dir.Off);
      } while (!ft.Finish());
      Drehen.Join();
    }

    private void DruckRun() {
      ft.SetLamp(oMinderdruck, Dir.On);
      ft.WaitForInput(iMinderdruck, false);
      ft.SetLamp(oMinderdruck, Dir.Off);
    }
    private void DrehenRun() {
      while (!ft.NotHalt) {
        ft.Pause(300);
        if (ft.GetInput(iBremsTaster)) {
          if (ft.GetCounter(iLichtschranke) > 0) {
            ft.SetCounter(iLichtschranke, 0);
            ft.SetLamp(oBremszylinder, Dir.On);
          } else ft.SetLamp(oBremszylinder, Dir.Off);
        }
      }
    }

    #region --- Programm-Kontrolle ---
    public ABSmain() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      // --- Open erstes ROBO an USB oder Intelligent Interface an COM
      //     während des Ablaufs von Action() gesperrt ---------------
      try {
        if (cboPortName.SelectedIndex == 0)
          ft.OpenInterface(IFTypen.ftROBO_first_USB, 0);
        else ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5);
        cmdAction.Enabled = false;
        cmdEnde.Text = "&HALT";
        lblStatus.Text = "--- Bei der Arbeit ---";
        lblHinweis.Text = "--- Ende : HALT-Button oder ESC-Taste ---";

        Action();        // --- Haupt-Routine der Anwendung

        ft.ClearMotors();
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
      }
      finally {
        ft.CloseInterface();
        cmdAction.Enabled = true;
        cmdEnde.Text = "&ENDE";
        lblStatus.Text = "--- Auf ein Neues ---";
        lblHinweis.Text = "Nochmal : ACTION, sonst ENDE oder ESC-Taste";
        cmdAction.Focus();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      // --- Programmende nur, wenn Action nicht läuft ---
      if (cmdEnde.Text == "&HALT") ft.NotHalt = true; else this.Close();
    }

    private void formLoad(object sender, EventArgs e) {
      // --- Default-Interface : Erstes ROBO Interface an USB ----
      cboPortName.SelectedIndex = 0;
    }

    private void formClosing(object sender, FormClosingEventArgs e) {
      // --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ------
      if (cmdEnde.Text == "&HALT") e.Cancel = true;
    }
    #endregion

  }
}